@@ -1,21 +1,21 @@
+import asyncio
 import logging
 import os
-import time
-import aiohttp
 import ssl
-import certifi
+import time
+from typing import Any, Dict, Optional
 from urllib.parse import urlencode, urlparse
 
-from requests import status_codes, adapters, PreparedRequest
+import aiohttp
+import certifi
+from requests import PreparedRequest, adapters, status_codes
 
-from Tea.exceptions import TeaException, RequiredArgumentException, RetryError
+from Tea.exceptions import RequiredArgumentException, RetryError
 from Tea.model import TeaModel
 from Tea.request import TeaRequest
 from Tea.response import TeaResponse
 from Tea.stream import BaseStream
 
-from typing import Dict, Any, Optional
-
 DEFAULT_CONNECT_TIMEOUT = 5000
 DEFAULT_READ_TIMEOUT = 10000
 DEFAULT_POOL_SIZE = 10
@@ -27,8 +27,8 @@ logger.addHandler(ch)
 
 
 class TeaCore:
-    http_adapter = adapters.HTTPAdapter(DEFAULT_POOL_SIZE, DEFAULT_POOL_SIZE)
-    https_adapter = adapters.HTTPAdapter(DEFAULT_POOL_SIZE, DEFAULT_POOL_SIZE)
+    http_adapter = adapters.HTTPAdapter(pool_connections=DEFAULT_POOL_SIZE, pool_maxsize=DEFAULT_POOL_SIZE * 4)
+    https_adapter = adapters.HTTPAdapter(pool_connections=DEFAULT_POOL_SIZE, pool_maxsize=DEFAULT_POOL_SIZE * 4)
 
     @staticmethod
     def get_adapter(prefix):
@@ -93,18 +93,17 @@ class TeaCore:
 
     @staticmethod
     async def async_do_action(
-        request: TeaRequest,
-        runtime_option=None
+            request: TeaRequest,
+            runtime_option=None
     ) -> TeaResponse:
         runtime_option = runtime_option or {}
 
         url = TeaCore.compose_url(request)
         verify = not runtime_option.get('ignoreSSL', False)
-        connect_timeout = runtime_option.get('connectTimeout')
-        connect_timeout = connect_timeout if connect_timeout else DEFAULT_CONNECT_TIMEOUT
 
-        read_timeout = runtime_option.get('readTimeout')
-        read_timeout = read_timeout if read_timeout else DEFAULT_READ_TIMEOUT
+        timeout = runtime_option.get('timeout')
+        connect_timeout = runtime_option.get('connectTimeout') or timeout or DEFAULT_CONNECT_TIMEOUT
+        read_timeout = runtime_option.get('readTimeout') or timeout or DEFAULT_READ_TIMEOUT
 
         connect_timeout, read_timeout = (int(connect_timeout) / 1000, int(read_timeout) / 1000)
 
@@ -113,11 +112,15 @@ class TeaCore:
             proxy = runtime_option.get('httpProxy')
             if not proxy:
                 proxy = os.environ.get('HTTP_PROXY') or os.environ.get('http_proxy')
+        elif request.protocol.upper() == 'HTTPS':
+            proxy = runtime_option.get('httpsProxy')
+            if not proxy:
+                proxy = os.environ.get('HTTPS_PROXY') or os.environ.get('https_proxy')
 
         connector = None
         ca_cert = certifi.where()
         if ca_cert and request.protocol.upper() == 'HTTPS':
-            ssl_context = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH)
+            ssl_context = ssl.create_default_context(ssl.Purpose.SERVER_AUTH)
             ssl_context.load_verify_locations(ca_cert)
             connector = aiohttp.TCPConnector(
                 ssl=ssl_context,
@@ -130,7 +133,7 @@ class TeaCore:
             sock_connect=connect_timeout
         )
         async with aiohttp.ClientSession(
-            connector=connector
+                connector=connector
         ) as s:
             body = b''
             if isinstance(request.body, BaseStream):
@@ -159,8 +162,8 @@ class TeaCore:
 
     @staticmethod
     def do_action(
-        request: TeaRequest,
-        runtime_option=None
+            request: TeaRequest,
+            runtime_option=None
     ) -> TeaResponse:
         url = TeaCore.compose_url(request)
 
@@ -171,11 +174,9 @@ class TeaCore:
             verify = runtime_option.get('ca', True) if runtime_option.get('ca', True) is not None else True
         cert = runtime_option.get('cert', None)
 
-        connect_timeout = runtime_option.get('connectTimeout')
-        connect_timeout = connect_timeout if connect_timeout else DEFAULT_CONNECT_TIMEOUT
-
-        read_timeout = runtime_option.get('readTimeout')
-        read_timeout = read_timeout if read_timeout else DEFAULT_READ_TIMEOUT
+        timeout = runtime_option.get('timeout')
+        connect_timeout = runtime_option.get('connectTimeout') or timeout or DEFAULT_CONNECT_TIMEOUT
+        read_timeout = runtime_option.get('readTimeout') or timeout or DEFAULT_READ_TIMEOUT
 
         timeout = (int(connect_timeout) / 1000, int(read_timeout) / 1000)
 
@@ -264,6 +265,10 @@ class TeaCore:
 
         return back_off_time
 
+    @staticmethod
+    async def sleep_async(t):
+        await asyncio.sleep(t)
+
     @staticmethod
     def sleep(t):
         time.sleep(t)
